@@ -1665,7 +1665,7 @@ class GraphWidget(DOMWidget):
         This function acts as an alias for using GraphWidget.graph_layout property
         e.g. w.graph_layout = 'organic' has the same effect
         as using w.set_graph_layout('organic').
-        Setting w.graph_layout = {'algorithm': 'organic', 'options': {}} works as well,
+        Setting w.graph_layout = {'algorithm': 'organic'} works as well,
         which corresponds to using value given through the associated getter.
         In case you want to use the edge routers
         you should set a custom node position mapping as well.
